import math

class Cp:
    def __init__(self, filename):
        with open(filename, 'r') as cp:
            lines = cp.readlines()

        lines = [line.split(' ') for line in lines]
        self.lines = [CpLine(int(type), float(x1), float(y1), float(
            x2), float(y2)) for [type, x1, y1, x2, y2] in lines]

        xVals = sum([[x.x1, x.x2] for x in self.lines], [])
        yVals = sum([[x.y1, x.y2] for x in self.lines], [])

        self.minX = min(xVals)
        self.maxX = max(xVals)
        self.minY = min(yVals)
        self.maxY = max(yVals)

    def size(self):
        width = math.ceil(self.maxX-self.minX)
        height = math.ceil(self.maxY-self.minY)

        return width, height


class CpLine:
    def __init__(self, type: int, x1: float, y1: float, x2: float, y2: float) -> None:
        self.type = type
        self.x1 = x1
        self.y1 = y1
        self.x2 = x2
        self.y2 = y2

    def color(self):
        if (self.type == 1):
            return (0, 0, 0)
        if (self.type == 2):
            return (255, 0, 0)
        if (self.type == 3):
            return (0, 0, 255)
        if (self.type == 4):
            return (193, 193, 193)

        raise ValueError("Unknown line type in .cp file")


from .cp import Cp

from PIL import Image, ImageDraw

factor = 8

margin = 20

def cp2png(infile, outfile):
    cp = Cp(infile)

    width, height = cp.size()

    with Image.new('RGB', (width * factor + 2 * margin, height * factor + 2 * margin)) as im:
        draw = ImageDraw.Draw(im)

        # Fill background
        draw.rectangle([0, 0, width * factor + 2 * margin, height * factor + 2 * margin],
                       fill=(255, 255, 255))

        for line in cp.lines:
            draw.line((((line.x1 - cp.minX) * factor) + margin, ((line.y1 - cp.minY) * factor) + margin,
                       ((line.x2 - cp.minX) * factor) + margin, ((line.y2 - cp.minY) * factor) + margin), fill=line.color(), width=2)

        # Apply anti alias
        im = im.resize(
            ((width * factor + (2 * margin)) // 2, (height * factor + (2 * margin)) // 2), resample=Image.ANTIALIAS)

        im.save(outfile, "PNG")

if __name__ == '__main__':
    cp2png('snek2.cp', 'snek2.png')
